Learn R Programming

visOmopResults (version 0.4.0)

visOmopResults-package: visOmopResults: Graphs and Tables for OMOP Results

Description

logo

Provides methods to transform omop_result objects into formatted tables and figures, facilitating the visualization of study results working with the Observational Medical Outcomes Partnership (OMOP) Common Data Model.

Arguments

Author

Maintainer: Núria Mercadé-Besora [email protected] (ORCID)

Authors:

See Also