Learn R Programming

visOmopResults (version 0.3.0)

tidy.summarised_result: Get a tidy visualization of a summarised_result object

Description

[Experimental] Provides tools for obtaining a tidy version of a summarised_result object. If the summarised results object contains settings, these will be transformed into columns.

Usage

# S3 method for summarised_result
tidy(
  x,
  splitGroup = TRUE,
  splitStrata = TRUE,
  splitAdditional = TRUE,
  addSettings = TRUE,
  pivotEstimatesBy = "estimate_name",
  nameStyle = NULL,
  ...
)

Value

A tibble.

Arguments

x

A summarised_result.

splitGroup

If TRUE it will split the group name-level column pair.

splitStrata

If TRUE it will split the group name-level column pair.

splitAdditional

If TRUE it will split the group name-level column pair.

addSettings

Whether to add settings as columns or not.

pivotEstimatesBy

Names from which pivot wider the estimate values. If NULL the table will not be pivotted.

nameStyle

Name style (glue package specifications) to customise names when pivotting estimates. If NULL standard tidyr::pivot_wider formatting will be used.

...

For compatibility (not used).

Examples

Run this code
result <- mockSummarisedResult()

result |> tidy()

Run the code above in your browser using DataLab