- result
A <summarised_result> object.
- estimateName
A named list of estimate names to join, sorted by
computation order. Use <...> to indicate estimate names.
- header
A vector specifying the elements to include in the header.
The order of elements matters, with the first being the topmost header.
Elements in header can be:
- settingsColumn
A character vector with the names of settings to
include in the table. To see options use settingsColumns(result).
- groupColumn
Columns to use as group labels, to see options use
tableColumns(result). By default, the name of the new group will be the
tidy* column names separated by ";". To specify a custom group name, use a
named list such as:
list("newGroupName" = c("variable_name", "variable_level")).
*tidy: The tidy format applied to column names replaces "_" with a space and
converts to sentence case. Use rename to customise specific column names.
- rename
A named vector to customise column names, e.g.,
c("Database name" = "cdm_name"). The function renames all column names
not specified here into a tidy* format.
- type
The desired format of the output table. See tableType() for
allowed options.
- hide
Columns to drop from the output table. By default, result_id and
estimate_type are always dropped.
- columnOrder
Character vector establishing the position of the columns
in the formatted table. Columns in either header, groupColumn, or hide will
be ignored.
- factor
A named list where names refer to columns (see available columns
in tableColumns()) and list elements are the level order of that column
to arrange the results. The column order in the list will be used for
arranging the result.
- style
A character string or custom R code to define the visual
formatting of the table. This argument can be provided in two ways:
Pre-defined Styles (Character String): Use a name for a built-in style
(e.g., "darwin"). See tableStyle() for available options.
Custom Code (Advanced): Supply a block of custom R code. This code must be
specific to the table type. See tableStyleCode() for structural examples.
- showMinCellCount
If TRUE, suppressed estimates will be indicated with
"<{min_cell_count}", otherwise, the default na defined in .options will be
used.
- .options
A named list with additional formatting options.
visOmopResults::tableOptions() shows allowed arguments and their default values.